@@ -9,4 +9,4 @@ from simpler.profiling import tic, toc, deep_size
 from simpler.sparql import dbpedia, entity_types
 from simpler.terminal import getch
 from simpler.validation import assert_set, assert_str, assert_number, assert_id, assert_mail, assert_exists
-from simpler.web import download_file, DownloaderPool
\ No newline at end of file
+from simpler.web import download_file, DownloaderPool, throttle
\ No newline at end of file
